pub struct BreakpointHitOutcome {
pub matched: bool,
pub should_stop: bool,
pub log_messages: Vec<String>,
}Expand description
Result of applying a runtime breakpoint hit to stored breakpoint metadata.
Fields
matched: boolTrue when at least one verified breakpoint matched the file/line location.
should_stop: boolTrue when execution should stop and emit a stopped event.
log_messages: Vec<String>Logpoint messages to emit as output events.