DapMessage

Enum DapMessage 

pub enum DapMessage {
    Request {
        seq: i64,
        command: String,
        arguments: Option<Value>,
    },
    Response {
        seq: i64,
        request_seq: i64,
        success: bool,
        command: String,
        body: Option<Value>,
        message: Option<String>,
    },
    Event {
        seq: i64,
        event: String,
        body: Option<Value>,
    },
}
Represents a DAP message, which can be a request, response, or event.

Variants



Request

A request from the client to the debug adapter.

Fields

seq: i64

Sequence number of the request.

command: String

The command to execute.

arguments: Option<Value>

Arguments for the command.



Response

A response from the debug adapter to a client request.

Fields

seq: i64

Sequence number of the response.

request_seq: i64

Sequence number of the corresponding request.

success: bool

Indicates whether the request was successful.

command: String

The command that was executed.

body: Option<Value>

The body of the response.

message: Option<String>

An optional message providing additional information.



Event

An event from the debug adapter to the client.

Fields

seq: i64

Sequence number of the event.

event: String

The type of event.

body: Option<Value>

The body of the event.