pub struct Scope {
pub name: String,
pub presentation_hint: Option<String>,
pub variables_reference: i64,
pub expensive: bool,
pub named_variables: Option<i64>,
pub indexed_variables: Option<i64>,
}Expand description
A scope within a stack frame
Fields
name: StringScope name (e.g., “Locals”, “Globals”)
presentation_hint: Option<String>Presentation hint (“arguments”, “locals”, “registers”)
variables_reference: i64Reference to the variables in this scope
expensive: boolWhether fetching variables is expensive
named_variables: Option<i64>Number of named child variables; can be used as a hint for the client to optimize pagination
indexed_variables: Option<i64>Number of indexed child variables; can be used as a hint for the client to optimize pagination