pub struct StackFrame {
pub id: i32,
pub name: String,
pub source: Source,
pub line: i32,
pub column: i32,
pub end_line: Option<i32>,
pub end_column: Option<i32>,
}Expand description
Stack frame information used by the debug adapter.
Corresponds to the DAP StackFrame type in the stackTrace response.
Fields
id: i32Unique numeric identifier for this frame within the current stopped state.
name: StringHuman-readable display name for the frame (e.g. "main::foo").
source: SourceSource file that contains this frame’s code.
line: i321-based line number of the current instruction in the frame.
column: i321-based column number of the current instruction in the frame.
end_line: Option<i32>1-based end line of the range covered by this frame, if known.
end_column: Option<i32>1-based end column of the range covered by this frame, if known.
Implementations