pub enum DapMessage {
Request {
seq: i64,
command: String,
arguments: Option<Value>,
},
Response {
seq: i64,
request_seq: i64,
success: bool,
command: String,
body: Option<Value>,
message: Option<String>,
},
Event {
seq: i64,
event: String,
body: Option<Value>,
},
}Expand description
Represents a DAP message, which can be a request, response, or event.
Variants
Request
A request from the client to the debug adapter.
Fields
Response
A response from the debug adapter to a client request.
Fields
Event
An event from the debug adapter to the client.